@@ -4,7 +4,7 @@
 modname = 'collaboration'
 distname = 'cubicweb-collaboration'
 
-numversion = (0, 2, 0)
+numversion = (1, 0, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -13,8 +13,8 @@ author_email = 'contact@logilab.fr'
 description = 'Cube for providing facilities for cooperative entity handling'
 web = 'http://www.cubicweb.org/project/%s' % distname
 
-__depends__ =  {'cubicweb': '>= 3.17.14',
-                'cubicweb-container': '>= 2.4.0',
+__depends__ =  {'cubicweb': '>= 3.18',
+                'cubicweb-container': '>= 2.6.0',
                }
 __recommends__ = {}
 
