@@ -15,12 +15,4 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
-"""cubicweb-collaboration postcreate script, executed at instance creation time or when
-the cube is added to an existing instance.
-
-You could setup site properties or a workflow here for example.
-"""
-_ = unicode
-
-# Example of site property change
-set_property('ui.site-title', _("Collaboration cube"))
+"""cubicweb-collaboration postcreate script"""
