@@ -28,12 +28,6 @@ class can_write(RelationType):
     subject = 'CWUser'
 
 
-class frozen(RelationType):
-    """Determine whether the collaborative entity can be updated or not."""
-    object = 'Boolean'
-    default = False
-
-
 class collaborates_on(RelationType):
     subject = 'CWUser'
     cardinality = '**'
