@@ -96,26 +96,22 @@ class CollaborationMixin(object):
                {'pattern': pattern})
         return [row[0] for row in self.request().execute(rql)]
 
-    def _setup_ce(self, req, collaborators=None, freeze=None,
+    def _setup_ce(self, req, collaborators=None,
                   **extra_attributes):
         entity = req.entity_from_eid(self.ce_eid)
         if extra_attributes:
-            for attr in extra_attributes.iteritems():
-                entity.cw_set(**dict([attr]))
+            entity.cw_set(**extra_attributes)
         adapted = entity.cw_adapt_to('ICollaborative')
         if collaborators is not None:
             adapted.set_collaborators(collaborators)
-        if freeze is not None:
-            adapted.set_frozen(freeze)
 
-    def setup_ce(self, as_user='author', freeze=None, collaborators=None, **extra_attributes):
+    def setup_ce(self, as_user='author', collaborators=None, **extra_attributes):
         with self.do_as_user(as_user) as req:
             self._setup_ce(req,
-                           freeze=freeze,
                            collaborators=collaborators,
                            **extra_attributes)
 
-    def assert_setup_ce_raises(self, exception, as_user=None, freeze=None, collaborators=None,
+    def assert_setup_ce_raises(self, exception, as_user=None, collaborators=None,
                                **extra_attributes):
         if as_user is not None:
             login = self.request().entity_from_eid(as_user).login
@@ -125,7 +121,6 @@ class CollaborationMixin(object):
             req = cnx.request()
             with self.assertRaises(exception):
                 self._setup_ce(req,
-                               freeze=freeze,
                                collaborators=collaborators,
                                **extra_attributes)
                 cnx.commit()
@@ -169,6 +164,8 @@ class CollaborationMixin(object):
         self.assertEqual(getattr(cloned_ent, clone_rtype)[0].eid, test_ent.eid)
         self.assertNotEqual(cloned_ent.eid, test_ent.eid)
         self.assertEqual(cloned_ent.description, test_ent.description)
+        wf_clone = cloned_ent.cw_adapt_to('IWorkflowable')
+        self.assertEqual(wf_clone.state, 'wfs_mutable')
 
         getattr_entities = lambda entities, name: frozenset(getattr(_e, name)
                                                             for _e in entities)
